# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

package OpenIPMI;
use base qw(Exporter);
use base qw(DynaLoader);
package OpenIPMIc;
bootstrap OpenIPMI;
package OpenIPMI;
@EXPORT = qw();

# ---------- BASE METHODS -------------

package OpenIPMI;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package OpenIPMI;

*enable_debug_malloc = *OpenIPMIc::enable_debug_malloc;
*enable_debug_msg = *OpenIPMIc::enable_debug_msg;
*disable_debug_msg = *OpenIPMIc::disable_debug_msg;
*enable_debug_rawmsg = *OpenIPMIc::enable_debug_rawmsg;
*disable_debug_rawmsg = *OpenIPMIc::disable_debug_rawmsg;
*init_glib = *OpenIPMIc::init_glib;
*init_glib12 = *OpenIPMIc::init_glib12;
*init_tcl = *OpenIPMIc::init_tcl;
*init_posix = *OpenIPMIc::init_posix;
*init = *OpenIPMIc::init;
*shutdown_everything = *OpenIPMIc::shutdown_everything;
*wait_io = *OpenIPMIc::wait_io;
*open_domain = *OpenIPMIc::open_domain;
*open_domain2 = *OpenIPMIc::open_domain2;
*open_domain3 = *OpenIPMIc::open_domain3;
*parse_args_iter_help = *OpenIPMIc::parse_args_iter_help;
*parse_option_help = *OpenIPMIc::parse_option_help;
*add_domain_change_handler = *OpenIPMIc::add_domain_change_handler;
*remove_domain_change_handler = *OpenIPMIc::remove_domain_change_handler;
*set_log_handler = *OpenIPMIc::set_log_handler;
*color_string = *OpenIPMIc::color_string;
*lanparm_parm_to_str = *OpenIPMIc::lanparm_parm_to_str;
*lanparm_str_to_parm = *OpenIPMIc::lanparm_str_to_parm;
*lanconfig_enum_val = *OpenIPMIc::lanconfig_enum_val;
*lanconfig_enum_idx = *OpenIPMIc::lanconfig_enum_idx;
*pef_parm_to_str = *OpenIPMIc::pef_parm_to_str;
*pef_str_to_parm = *OpenIPMIc::pef_str_to_parm;
*pefconfig_enum_val = *OpenIPMIc::pefconfig_enum_val;
*pefconfig_enum_idx = *OpenIPMIc::pefconfig_enum_idx;
*solparm_parm_to_str = *OpenIPMIc::solparm_parm_to_str;
*solparm_str_to_parm = *OpenIPMIc::solparm_str_to_parm;
*solconfig_enum_val = *OpenIPMIc::solconfig_enum_val;
*solconfig_enum_idx = *OpenIPMIc::solconfig_enum_idx;
*get_threshold_access_support_string = *OpenIPMIc::get_threshold_access_support_string;
*get_hysteresis_support_string = *OpenIPMIc::get_hysteresis_support_string;
*get_event_support_string = *OpenIPMIc::get_event_support_string;
*channel_medium_string = *OpenIPMIc::channel_medium_string;
*channel_protocol_string = *OpenIPMIc::channel_protocol_string;
*channel_session_support_string = *OpenIPMIc::channel_session_support_string;
*channel_access_mode_string = *OpenIPMIc::channel_access_mode_string;
*privilege_string = *OpenIPMIc::privilege_string;
*authtype_string = *OpenIPMIc::authtype_string;
*get_error_string = *OpenIPMIc::get_error_string;
*alloc_empty_args = *OpenIPMIc::alloc_empty_args;
*alloc_parse_args = *OpenIPMIc::alloc_parse_args;
*fru_index_to_str = *OpenIPMIc::fru_index_to_str;
*fru_str_to_index = *OpenIPMIc::fru_str_to_index;
*alloc_cmdlang = *OpenIPMIc::alloc_cmdlang;
*cmdlang_set_evinfo = *OpenIPMIc::cmdlang_set_evinfo;
*cmdlang_get_evinfo = *OpenIPMIc::cmdlang_get_evinfo;
*set_cmdlang_global_err_handler = *OpenIPMIc::set_cmdlang_global_err_handler;
*set_cmdlang_event_handler = *OpenIPMIc::set_cmdlang_event_handler;
*sol_state_string = *OpenIPMIc::sol_state_string;

############# Class : OpenIPMI::strconstarray ##############

package OpenIPMI::strconstarray;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
*swig_val_get = *OpenIPMIc::strconstarray_val_get;
*swig_val_set = *OpenIPMIc::strconstarray_val_set;
*swig_len_get = *OpenIPMIc::strconstarray_len_get;
*swig_len_set = *OpenIPMIc::strconstarray_len_set;
sub new {
    my $pkg = shift;
    my $self = OpenIPMIc::new_strconstarray(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_strconstarray($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::argarray ##############

package OpenIPMI::argarray;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
*swig_val_get = *OpenIPMIc::argarray_val_get;
*swig_val_set = *OpenIPMIc::argarray_val_set;
*swig_len_get = *OpenIPMIc::argarray_len_get;
*swig_len_set = *OpenIPMIc::argarray_len_set;
sub new {
    my $pkg = shift;
    my $self = OpenIPMIc::new_argarray(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_argarray($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::iargarray ##############

package OpenIPMI::iargarray;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
*swig_val_get = *OpenIPMIc::iargarray_val_get;
*swig_val_set = *OpenIPMIc::iargarray_val_set;
*swig_len_get = *OpenIPMIc::iargarray_len_get;
*swig_len_set = *OpenIPMIc::iargarray_len_set;
sub new {
    my $pkg = shift;
    my $self = OpenIPMIc::new_iargarray(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_iargarray($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_domain_t ##############

package OpenIPMI::ipmi_domain_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
*get_name = *OpenIPMIc::ipmi_domain_t_get_name;
*get_id = *OpenIPMIc::ipmi_domain_t_get_id;
*get_guid = *OpenIPMIc::ipmi_domain_t_get_guid;
*close = *OpenIPMIc::ipmi_domain_t_close;
*add_connect_change_handler = *OpenIPMIc::ipmi_domain_t_add_connect_change_handler;
*remove_connect_change_handler = *OpenIPMIc::ipmi_domain_t_remove_connect_change_handler;
*iterate_connections = *OpenIPMIc::ipmi_domain_t_iterate_connections;
*activate_connection = *OpenIPMIc::ipmi_domain_t_activate_connection;
*is_connection_active = *OpenIPMIc::ipmi_domain_t_is_connection_active;
*is_connection_up = *OpenIPMIc::ipmi_domain_t_is_connection_up;
*num_connection_ports = *OpenIPMIc::ipmi_domain_t_num_connection_ports;
*is_connection_port_up = *OpenIPMIc::ipmi_domain_t_is_connection_port_up;
*get_port_info = *OpenIPMIc::ipmi_domain_t_get_port_info;
*get_connection_args = *OpenIPMIc::ipmi_domain_t_get_connection_args;
*get_connection_type = *OpenIPMIc::ipmi_domain_t_get_connection_type;
*add_entity_update_handler = *OpenIPMIc::ipmi_domain_t_add_entity_update_handler;
*remove_entity_update_handler = *OpenIPMIc::ipmi_domain_t_remove_entity_update_handler;
*iterate_entities = *OpenIPMIc::ipmi_domain_t_iterate_entities;
*add_mc_update_handler = *OpenIPMIc::ipmi_domain_t_add_mc_update_handler;
*remove_mc_update_handler = *OpenIPMIc::ipmi_domain_t_remove_mc_update_handler;
*iterate_mcs = *OpenIPMIc::ipmi_domain_t_iterate_mcs;
*get_type = *OpenIPMIc::ipmi_domain_t_get_type;
*start_ipmb_mc_scan = *OpenIPMIc::ipmi_domain_t_start_ipmb_mc_scan;
*start_full_ipmb_scan = *OpenIPMIc::ipmi_domain_t_start_full_ipmb_scan;
*send_command_addr = *OpenIPMIc::ipmi_domain_t_send_command_addr;
*detect_presence_changes = *OpenIPMIc::ipmi_domain_t_detect_presence_changes;
*set_sel_rescan_time = *OpenIPMIc::ipmi_domain_t_set_sel_rescan_time;
*get_sel_rescan_time = *OpenIPMIc::ipmi_domain_t_get_sel_rescan_time;
*set_ipmb_rescan_time = *OpenIPMIc::ipmi_domain_t_set_ipmb_rescan_time;
*get_ipmb_rescan_time = *OpenIPMIc::ipmi_domain_t_get_ipmb_rescan_time;
*add_event_handler = *OpenIPMIc::ipmi_domain_t_add_event_handler;
*remove_event_handler = *OpenIPMIc::ipmi_domain_t_remove_event_handler;
*first_event = *OpenIPMIc::ipmi_domain_t_first_event;
*last_event = *OpenIPMIc::ipmi_domain_t_last_event;
*next_event = *OpenIPMIc::ipmi_domain_t_next_event;
*prev_event = *OpenIPMIc::ipmi_domain_t_prev_event;
*sel_count = *OpenIPMIc::ipmi_domain_t_sel_count;
*sel_entries_used = *OpenIPMIc::ipmi_domain_t_sel_entries_used;
*reread_sels = *OpenIPMIc::ipmi_domain_t_reread_sels;
*fru_alloc = *OpenIPMIc::ipmi_domain_t_fru_alloc;
*get_pet = *OpenIPMIc::ipmi_domain_t_get_pet;
*create_sol = *OpenIPMIc::ipmi_domain_t_create_sol;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_domain_id_t ##############

package OpenIPMI::ipmi_domain_id_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_domain_id_t($self);
        delete $OWNER{$self};
    }
}

*cmp = *OpenIPMIc::ipmi_domain_id_t_cmp;
*to_domain = *OpenIPMIc::ipmi_domain_id_t_to_domain;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_args_t ##############

package OpenIPMI::ipmi_args_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_args_t($self);
        delete $OWNER{$self};
    }
}

*get_type = *OpenIPMIc::ipmi_args_t_get_type;
*get_val = *OpenIPMIc::ipmi_args_t_get_val;
*set_val = *OpenIPMIc::ipmi_args_t_set_val;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_entity_t ##############

package OpenIPMI::ipmi_entity_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
*get_domain = *OpenIPMIc::ipmi_entity_t_get_domain;
*get_name = *OpenIPMIc::ipmi_entity_t_get_name;
*get_id = *OpenIPMIc::ipmi_entity_t_get_id;
*iterate_children = *OpenIPMIc::ipmi_entity_t_iterate_children;
*iterate_parents = *OpenIPMIc::ipmi_entity_t_iterate_parents;
*iterate_sensors = *OpenIPMIc::ipmi_entity_t_iterate_sensors;
*iterate_controls = *OpenIPMIc::ipmi_entity_t_iterate_controls;
*add_presence_handler = *OpenIPMIc::ipmi_entity_t_add_presence_handler;
*remove_presence_handler = *OpenIPMIc::ipmi_entity_t_remove_presence_handler;
*add_sensor_update_handler = *OpenIPMIc::ipmi_entity_t_add_sensor_update_handler;
*remove_sensor_update_handler = *OpenIPMIc::ipmi_entity_t_remove_sensor_update_handler;
*add_control_update_handler = *OpenIPMIc::ipmi_entity_t_add_control_update_handler;
*remove_control_update_handler = *OpenIPMIc::ipmi_entity_t_remove_control_update_handler;
*add_fru_update_handler = *OpenIPMIc::ipmi_entity_t_add_fru_update_handler;
*remove_fru_update_handler = *OpenIPMIc::ipmi_entity_t_remove_fru_update_handler;
*add_fru_update_werr_handler = *OpenIPMIc::ipmi_entity_t_add_fru_update_werr_handler;
*remove_fru_update_werr_handler = *OpenIPMIc::ipmi_entity_t_remove_fru_update_werr_handler;
*get_type = *OpenIPMIc::ipmi_entity_t_get_type;
*is_fru = *OpenIPMIc::ipmi_entity_t_is_fru;
*get_id_string = *OpenIPMIc::ipmi_entity_t_get_id_string;
*get_entity_id = *OpenIPMIc::ipmi_entity_t_get_entity_id;
*get_entity_id_string = *OpenIPMIc::ipmi_entity_t_get_entity_id_string;
*get_entity_instance = *OpenIPMIc::ipmi_entity_t_get_entity_instance;
*get_entity_device_channel = *OpenIPMIc::ipmi_entity_t_get_entity_device_channel;
*get_entity_device_address = *OpenIPMIc::ipmi_entity_t_get_entity_device_address;
*get_fru = *OpenIPMIc::ipmi_entity_t_get_fru;
*get_presence_sensor_always_there = *OpenIPMIc::ipmi_entity_t_get_presence_sensor_always_there;
*is_child = *OpenIPMIc::ipmi_entity_t_is_child;
*is_parent = *OpenIPMIc::ipmi_entity_t_is_parent;
*get_channel = *OpenIPMIc::ipmi_entity_t_get_channel;
*get_lun = *OpenIPMIc::ipmi_entity_t_get_lun;
*get_oem = *OpenIPMIc::ipmi_entity_t_get_oem;
*get_access_address = *OpenIPMIc::ipmi_entity_t_get_access_address;
*get_private_bus_id = *OpenIPMIc::ipmi_entity_t_get_private_bus_id;
*get_device_type = *OpenIPMIc::ipmi_entity_t_get_device_type;
*get_device_modifier = *OpenIPMIc::ipmi_entity_t_get_device_modifier;
*get_slave_address = *OpenIPMIc::ipmi_entity_t_get_slave_address;
*get_mc_id = *OpenIPMIc::ipmi_entity_t_get_mc_id;
*get_is_logical_fru = *OpenIPMIc::ipmi_entity_t_get_is_logical_fru;
*get_fru_device_id = *OpenIPMIc::ipmi_entity_t_get_fru_device_id;
*get_ACPI_system_power_notify_required = *OpenIPMIc::ipmi_entity_t_get_ACPI_system_power_notify_required;
*get_ACPI_device_power_notify_required = *OpenIPMIc::ipmi_entity_t_get_ACPI_device_power_notify_required;
*get_controller_logs_init_agent_errors = *OpenIPMIc::ipmi_entity_t_get_controller_logs_init_agent_errors;
*get_log_init_agent_errors_accessing = *OpenIPMIc::ipmi_entity_t_get_log_init_agent_errors_accessing;
*get_global_init = *OpenIPMIc::ipmi_entity_t_get_global_init;
*get_chassis_device = *OpenIPMIc::ipmi_entity_t_get_chassis_device;
*get_bridge = *OpenIPMIc::ipmi_entity_t_get_bridge;
*get_IPMB_event_generator = *OpenIPMIc::ipmi_entity_t_get_IPMB_event_generator;
*get_IPMB_event_receiver = *OpenIPMIc::ipmi_entity_t_get_IPMB_event_receiver;
*get_FRU_inventory_device = *OpenIPMIc::ipmi_entity_t_get_FRU_inventory_device;
*get_SEL_device = *OpenIPMIc::ipmi_entity_t_get_SEL_device;
*get_SDR_repository_device = *OpenIPMIc::ipmi_entity_t_get_SDR_repository_device;
*get_sensor_device = *OpenIPMIc::ipmi_entity_t_get_sensor_device;
*get_address_span = *OpenIPMIc::ipmi_entity_t_get_address_span;
*get_dlr_id = *OpenIPMIc::ipmi_entity_t_get_dlr_id;
*is_present = *OpenIPMIc::ipmi_entity_t_is_present;
*get_physical_slot_num = *OpenIPMIc::ipmi_entity_t_get_physical_slot_num;
*is_hot_swappable = *OpenIPMIc::ipmi_entity_t_is_hot_swappable;
*supports_managed_hot_swap = *OpenIPMIc::ipmi_entity_t_supports_managed_hot_swap;
*add_hot_swap_handler = *OpenIPMIc::ipmi_entity_t_add_hot_swap_handler;
*remove_hot_swap_handler = *OpenIPMIc::ipmi_entity_t_remove_hot_swap_handler;
*get_hot_swap_state = *OpenIPMIc::ipmi_entity_t_get_hot_swap_state;
*supports_auto_activate_time = *OpenIPMIc::ipmi_entity_t_supports_auto_activate_time;
*get_auto_activate_time = *OpenIPMIc::ipmi_entity_t_get_auto_activate_time;
*set_auto_activate_time = *OpenIPMIc::ipmi_entity_t_set_auto_activate_time;
*supports_auto_deactivate_time = *OpenIPMIc::ipmi_entity_t_supports_auto_deactivate_time;
*get_auto_deactivate_time = *OpenIPMIc::ipmi_entity_t_get_auto_deactivate_time;
*set_auto_deactivate_time = *OpenIPMIc::ipmi_entity_t_set_auto_deactivate_time;
*set_activation_requested = *OpenIPMIc::ipmi_entity_t_set_activation_requested;
*activate = *OpenIPMIc::ipmi_entity_t_activate;
*deactivate = *OpenIPMIc::ipmi_entity_t_deactivate;
*check_hot_swap_state = *OpenIPMIc::ipmi_entity_t_check_hot_swap_state;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_entity_id_t ##############

package OpenIPMI::ipmi_entity_id_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_entity_id_t($self);
        delete $OWNER{$self};
    }
}

*cmp = *OpenIPMIc::ipmi_entity_id_t_cmp;
*to_entity = *OpenIPMIc::ipmi_entity_id_t_to_entity;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_fru_t ##############

package OpenIPMI::ipmi_fru_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_fru_t($self);
        delete $OWNER{$self};
    }
}

*get_domain_id = *OpenIPMIc::ipmi_fru_t_get_domain_id;
*str_to_index = *OpenIPMIc::ipmi_fru_t_str_to_index;
*get = *OpenIPMIc::ipmi_fru_t_get;
*get_num_multi_records = *OpenIPMIc::ipmi_fru_t_get_num_multi_records;
*get_multirecord = *OpenIPMIc::ipmi_fru_t_get_multirecord;
*set = *OpenIPMIc::ipmi_fru_t_set;
*set_array = *OpenIPMIc::ipmi_fru_t_set_array;
*set_multirecord = *OpenIPMIc::ipmi_fru_t_set_multirecord;
*set_multirecord_array = *OpenIPMIc::ipmi_fru_t_set_multirecord_array;
*add_area = *OpenIPMIc::ipmi_fru_t_add_area;
*delete_area = *OpenIPMIc::ipmi_fru_t_delete_area;
*area_get_offset = *OpenIPMIc::ipmi_fru_t_area_get_offset;
*area_get_length = *OpenIPMIc::ipmi_fru_t_area_get_length;
*area_set_offset = *OpenIPMIc::ipmi_fru_t_area_set_offset;
*area_set_length = *OpenIPMIc::ipmi_fru_t_area_set_length;
*area_get_used_length = *OpenIPMIc::ipmi_fru_t_area_get_used_length;
*write = *OpenIPMIc::ipmi_fru_t_write;
*multi_record_get_root_node = *OpenIPMIc::ipmi_fru_t_multi_record_get_root_node;
*get_root_node = *OpenIPMIc::ipmi_fru_t_get_root_node;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_fru_node_t ##############

package OpenIPMI::ipmi_fru_node_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_fru_node_t($self);
        delete $OWNER{$self};
    }
}

*get_field = *OpenIPMIc::ipmi_fru_node_t_get_field;
*get_enum_val = *OpenIPMIc::ipmi_fru_node_t_get_enum_val;
*set_field = *OpenIPMIc::ipmi_fru_node_t_set_field;
*settable = *OpenIPMIc::ipmi_fru_node_t_settable;
*get_subtype = *OpenIPMIc::ipmi_fru_node_t_get_subtype;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_mc_t ##############

package OpenIPMI::ipmi_mc_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
*get_domain = *OpenIPMIc::ipmi_mc_t_get_domain;
*get_name = *OpenIPMIc::ipmi_mc_t_get_name;
*get_id = *OpenIPMIc::ipmi_mc_t_get_id;
*get_guid = *OpenIPMIc::ipmi_mc_t_get_guid;
*provides_device_sdrs = *OpenIPMIc::ipmi_mc_t_provides_device_sdrs;
*device_available = *OpenIPMIc::ipmi_mc_t_device_available;
*chassis_support = *OpenIPMIc::ipmi_mc_t_chassis_support;
*bridge_support = *OpenIPMIc::ipmi_mc_t_bridge_support;
*ipmb_event_generator_support = *OpenIPMIc::ipmi_mc_t_ipmb_event_generator_support;
*ipmb_event_receiver_support = *OpenIPMIc::ipmi_mc_t_ipmb_event_receiver_support;
*fru_inventory_support = *OpenIPMIc::ipmi_mc_t_fru_inventory_support;
*sel_device_support = *OpenIPMIc::ipmi_mc_t_sel_device_support;
*sdr_repository_support = *OpenIPMIc::ipmi_mc_t_sdr_repository_support;
*sensor_device_support = *OpenIPMIc::ipmi_mc_t_sensor_device_support;
*device_id = *OpenIPMIc::ipmi_mc_t_device_id;
*device_revision = *OpenIPMIc::ipmi_mc_t_device_revision;
*major_fw_revision = *OpenIPMIc::ipmi_mc_t_major_fw_revision;
*minor_fw_revision = *OpenIPMIc::ipmi_mc_t_minor_fw_revision;
*major_version = *OpenIPMIc::ipmi_mc_t_major_version;
*minor_version = *OpenIPMIc::ipmi_mc_t_minor_version;
*manufacturer_id = *OpenIPMIc::ipmi_mc_t_manufacturer_id;
*product_id = *OpenIPMIc::ipmi_mc_t_product_id;
*aux_fw_revision = *OpenIPMIc::ipmi_mc_t_aux_fw_revision;
*is_active = *OpenIPMIc::ipmi_mc_t_is_active;
*add_active_handler = *OpenIPMIc::ipmi_mc_t_add_active_handler;
*remove_active_handler = *OpenIPMIc::ipmi_mc_t_remove_active_handler;
*add_fully_up_handler = *OpenIPMIc::ipmi_mc_t_add_fully_up_handler;
*remove_fully_up_handler = *OpenIPMIc::ipmi_mc_t_remove_fully_up_handler;
*send_command = *OpenIPMIc::ipmi_mc_t_send_command;
*reset = *OpenIPMIc::ipmi_mc_t_reset;
*get_events_enable = *OpenIPMIc::ipmi_mc_t_get_events_enable;
*set_events_enable = *OpenIPMIc::ipmi_mc_t_set_events_enable;
*get_event_log_enable = *OpenIPMIc::ipmi_mc_t_get_event_log_enable;
*set_event_log_enable = *OpenIPMIc::ipmi_mc_t_set_event_log_enable;
*reread_sensors = *OpenIPMIc::ipmi_mc_t_reread_sensors;
*set_sel_rescan_time = *OpenIPMIc::ipmi_mc_t_set_sel_rescan_time;
*get_sel_rescan_time = *OpenIPMIc::ipmi_mc_t_get_sel_rescan_time;
*reread_sel = *OpenIPMIc::ipmi_mc_t_reread_sel;
*get_current_sel_time = *OpenIPMIc::ipmi_mc_t_get_current_sel_time;
*first_event = *OpenIPMIc::ipmi_mc_t_first_event;
*last_event = *OpenIPMIc::ipmi_mc_t_last_event;
*next_event = *OpenIPMIc::ipmi_mc_t_next_event;
*prev_event = *OpenIPMIc::ipmi_mc_t_prev_event;
*event_by_recid = *OpenIPMIc::ipmi_mc_t_event_by_recid;
*sel_count = *OpenIPMIc::ipmi_mc_t_sel_count;
*sel_entries_used = *OpenIPMIc::ipmi_mc_t_sel_entries_used;
*sel_get_major_version = *OpenIPMIc::ipmi_mc_t_sel_get_major_version;
*sel_get_minor_version = *OpenIPMIc::ipmi_mc_t_sel_get_minor_version;
*sel_get_num_entries = *OpenIPMIc::ipmi_mc_t_sel_get_num_entries;
*sel_get_free_bytes = *OpenIPMIc::ipmi_mc_t_sel_get_free_bytes;
*sel_get_overflow = *OpenIPMIc::ipmi_mc_t_sel_get_overflow;
*sel_get_supports_delete_sel = *OpenIPMIc::ipmi_mc_t_sel_get_supports_delete_sel;
*sel_get_supports_partial_add_sel = *OpenIPMIc::ipmi_mc_t_sel_get_supports_partial_add_sel;
*sel_get_supports_reserve_sel = *OpenIPMIc::ipmi_mc_t_sel_get_supports_reserve_sel;
*sel_get_supports_get_sel_allocation = *OpenIPMIc::ipmi_mc_t_sel_get_supports_get_sel_allocation;
*sel_get_last_addition_timestamp = *OpenIPMIc::ipmi_mc_t_sel_get_last_addition_timestamp;
*channel_get_info = *OpenIPMIc::ipmi_mc_t_channel_get_info;
*channel_get_access = *OpenIPMIc::ipmi_mc_t_channel_get_access;
*channel_set_access = *OpenIPMIc::ipmi_mc_t_channel_set_access;
*get_users = *OpenIPMIc::ipmi_mc_t_get_users;
*set_user = *OpenIPMIc::ipmi_mc_t_set_user;
*get_lanparm = *OpenIPMIc::ipmi_mc_t_get_lanparm;
*get_pef = *OpenIPMIc::ipmi_mc_t_get_pef;
*get_pet = *OpenIPMIc::ipmi_mc_t_get_pet;
*get_solparm = *OpenIPMIc::ipmi_mc_t_get_solparm;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_mcid_t ##############

package OpenIPMI::ipmi_mcid_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_mcid_t($self);
        delete $OWNER{$self};
    }
}

*cmp = *OpenIPMIc::ipmi_mcid_t_cmp;
*to_mc = *OpenIPMIc::ipmi_mcid_t_to_mc;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_event_t ##############

package OpenIPMI::ipmi_event_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_event_t($self);
        delete $OWNER{$self};
    }
}

*delete = *OpenIPMIc::ipmi_event_t_delete;
*get_mc_id = *OpenIPMIc::ipmi_event_t_get_mc_id;
*get_record_id = *OpenIPMIc::ipmi_event_t_get_record_id;
*get_type = *OpenIPMIc::ipmi_event_t_get_type;
*get_timestamp = *OpenIPMIc::ipmi_event_t_get_timestamp;
*get_data = *OpenIPMIc::ipmi_event_t_get_data;
*call_handler = *OpenIPMIc::ipmi_event_t_call_handler;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_sensor_t ##############

package OpenIPMI::ipmi_sensor_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
*get_name = *OpenIPMIc::ipmi_sensor_t_get_name;
*get_id = *OpenIPMIc::ipmi_sensor_t_get_id;
*add_event_handler = *OpenIPMIc::ipmi_sensor_t_add_event_handler;
*remove_event_handler = *OpenIPMIc::ipmi_sensor_t_remove_event_handler;
*set_event_enables = *OpenIPMIc::ipmi_sensor_t_set_event_enables;
*enable_events = *OpenIPMIc::ipmi_sensor_t_enable_events;
*disable_events = *OpenIPMIc::ipmi_sensor_t_disable_events;
*get_event_enables = *OpenIPMIc::ipmi_sensor_t_get_event_enables;
*rearm = *OpenIPMIc::ipmi_sensor_t_rearm;
*get_hysteresis = *OpenIPMIc::ipmi_sensor_t_get_hysteresis;
*set_hysteresis = *OpenIPMIc::ipmi_sensor_t_set_hysteresis;
*get_default_thresholds = *OpenIPMIc::ipmi_sensor_t_get_default_thresholds;
*set_thresholds = *OpenIPMIc::ipmi_sensor_t_set_thresholds;
*get_thresholds = *OpenIPMIc::ipmi_sensor_t_get_thresholds;
*get_value = *OpenIPMIc::ipmi_sensor_t_get_value;
*get_lun = *OpenIPMIc::ipmi_sensor_t_get_lun;
*get_num = *OpenIPMIc::ipmi_sensor_t_get_num;
*get_sensor_type_string = *OpenIPMIc::ipmi_sensor_t_get_sensor_type_string;
*get_sensor_type = *OpenIPMIc::ipmi_sensor_t_get_sensor_type;
*get_event_reading_type_string = *OpenIPMIc::ipmi_sensor_t_get_event_reading_type_string;
*get_event_reading_type = *OpenIPMIc::ipmi_sensor_t_get_event_reading_type;
*get_rate_unit_string = *OpenIPMIc::ipmi_sensor_t_get_rate_unit_string;
*get_rate_unit = *OpenIPMIc::ipmi_sensor_t_get_rate_unit;
*get_base_unit_string = *OpenIPMIc::ipmi_sensor_t_get_base_unit_string;
*get_base_unit = *OpenIPMIc::ipmi_sensor_t_get_base_unit;
*get_modifier_unit_string = *OpenIPMIc::ipmi_sensor_t_get_modifier_unit_string;
*get_modifier_unit = *OpenIPMIc::ipmi_sensor_t_get_modifier_unit;
*get_modifier_unit_use = *OpenIPMIc::ipmi_sensor_t_get_modifier_unit_use;
*get_percentage = *OpenIPMIc::ipmi_sensor_t_get_percentage;
*reading_name_string = *OpenIPMIc::ipmi_sensor_t_reading_name_string;
*get_entity_id = *OpenIPMIc::ipmi_sensor_t_get_entity_id;
*get_entity_instance = *OpenIPMIc::ipmi_sensor_t_get_entity_instance;
*get_entity = *OpenIPMIc::ipmi_sensor_t_get_entity;
*get_sensor_init_scanning = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_scanning;
*get_sensor_init_events = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_events;
*get_sensor_init_thresholds = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_thresholds;
*get_sensor_init_hysteresis = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_hysteresis;
*get_sensor_init_type = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_type;
*get_sensor_init_pu_events = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_pu_events;
*get_sensor_init_pu_scanning = *OpenIPMIc::ipmi_sensor_t_get_sensor_init_pu_scanning;
*get_ignore_if_no_entity = *OpenIPMIc::ipmi_sensor_t_get_ignore_if_no_entity;
*get_supports_auto_rearm = *OpenIPMIc::ipmi_sensor_t_get_supports_auto_rearm;
*get_threshold_access = *OpenIPMIc::ipmi_sensor_t_get_threshold_access;
*get_hysteresis_support = *OpenIPMIc::ipmi_sensor_t_get_hysteresis_support;
*get_event_support = *OpenIPMIc::ipmi_sensor_t_get_event_support;
*get_sensor_direction = *OpenIPMIc::ipmi_sensor_t_get_sensor_direction;
*is_readable = *OpenIPMIc::ipmi_sensor_t_is_readable;
*threshold_event_supported = *OpenIPMIc::ipmi_sensor_t_threshold_event_supported;
*threshold_settable = *OpenIPMIc::ipmi_sensor_t_threshold_settable;
*threshold_readable = *OpenIPMIc::ipmi_sensor_t_threshold_readable;
*threshold_reading_supported = *OpenIPMIc::ipmi_sensor_t_threshold_reading_supported;
*discrete_event_supported = *OpenIPMIc::ipmi_sensor_t_discrete_event_supported;
*discrete_event_readable = *OpenIPMIc::ipmi_sensor_t_discrete_event_readable;
*get_tolerance = *OpenIPMIc::ipmi_sensor_t_get_tolerance;
*get_accuracy = *OpenIPMIc::ipmi_sensor_t_get_accuracy;
*get_normal_min_specified = *OpenIPMIc::ipmi_sensor_t_get_normal_min_specified;
*get_normal_min = *OpenIPMIc::ipmi_sensor_t_get_normal_min;
*get_normal_max_specified = *OpenIPMIc::ipmi_sensor_t_get_normal_max_specified;
*get_normal_max = *OpenIPMIc::ipmi_sensor_t_get_normal_max;
*get_nominal_reading_specified = *OpenIPMIc::ipmi_sensor_t_get_nominal_reading_specified;
*get_nominal_reading = *OpenIPMIc::ipmi_sensor_t_get_nominal_reading;
*get_sensor_max = *OpenIPMIc::ipmi_sensor_t_get_sensor_max;
*get_sensor_min = *OpenIPMIc::ipmi_sensor_t_get_sensor_min;
*get_oem1 = *OpenIPMIc::ipmi_sensor_t_get_oem1;
*get_sensor_id = *OpenIPMIc::ipmi_sensor_t_get_sensor_id;
*get_mc = *OpenIPMIc::ipmi_sensor_t_get_mc;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_sensor_id_t ##############

package OpenIPMI::ipmi_sensor_id_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_sensor_id_t($self);
        delete $OWNER{$self};
    }
}

*cmp = *OpenIPMIc::ipmi_sensor_id_t_cmp;
*to_sensor = *OpenIPMIc::ipmi_sensor_id_t_to_sensor;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_control_t ##############

package OpenIPMI::ipmi_control_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
*get_name = *OpenIPMIc::ipmi_control_t_get_name;
*get_id = *OpenIPMIc::ipmi_control_t_get_id;
*get_type_string = *OpenIPMIc::ipmi_control_t_get_type_string;
*get_type = *OpenIPMIc::ipmi_control_t_get_type;
*get_entity_id = *OpenIPMIc::ipmi_control_t_get_entity_id;
*get_entity_instance = *OpenIPMIc::ipmi_control_t_get_entity_instance;
*get_entity = *OpenIPMIc::ipmi_control_t_get_entity;
*is_settable = *OpenIPMIc::ipmi_control_t_is_settable;
*is_readable = *OpenIPMIc::ipmi_control_t_is_readable;
*get_ignore_if_no_entity = *OpenIPMIc::ipmi_control_t_get_ignore_if_no_entity;
*get_control_id = *OpenIPMIc::ipmi_control_t_get_control_id;
*has_events = *OpenIPMIc::ipmi_control_t_has_events;
*get_num_vals = *OpenIPMIc::ipmi_control_t_get_num_vals;
*set_val = *OpenIPMIc::ipmi_control_t_set_val;
*get_val = *OpenIPMIc::ipmi_control_t_get_val;
*add_event_handler = *OpenIPMIc::ipmi_control_t_add_event_handler;
*remove_event_handler = *OpenIPMIc::ipmi_control_t_remove_event_handler;
*light_set_with_setting = *OpenIPMIc::ipmi_control_t_light_set_with_setting;
*light_is_color_supported = *OpenIPMIc::ipmi_control_t_light_is_color_supported;
*light_has_local_control = *OpenIPMIc::ipmi_control_t_light_has_local_control;
*set_light = *OpenIPMIc::ipmi_control_t_set_light;
*get_light = *OpenIPMIc::ipmi_control_t_get_light;
*get_num_light_values = *OpenIPMIc::ipmi_control_t_get_num_light_values;
*get_num_light_transitions = *OpenIPMIc::ipmi_control_t_get_num_light_transitions;
*get_light_color = *OpenIPMIc::ipmi_control_t_get_light_color;
*get_light_color_time = *OpenIPMIc::ipmi_control_t_get_light_color_time;
*identifier_set_val = *OpenIPMIc::ipmi_control_t_identifier_set_val;
*identifier_get_val = *OpenIPMIc::ipmi_control_t_identifier_get_val;
*identifier_get_max_length = *OpenIPMIc::ipmi_control_t_identifier_get_max_length;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_control_id_t ##############

package OpenIPMI::ipmi_control_id_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_control_id_t($self);
        delete $OWNER{$self};
    }
}

*cmp = *OpenIPMIc::ipmi_control_id_t_cmp;
*to_control = *OpenIPMIc::ipmi_control_id_t_to_control;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_channel_info_t ##############

package OpenIPMI::ipmi_channel_info_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_channel_info_t($self);
        delete $OWNER{$self};
    }
}

*copy = *OpenIPMIc::ipmi_channel_info_t_copy;
*get_channel = *OpenIPMIc::ipmi_channel_info_t_get_channel;
*get_medium = *OpenIPMIc::ipmi_channel_info_t_get_medium;
*get_protocol_type = *OpenIPMIc::ipmi_channel_info_t_get_protocol_type;
*get_session_support = *OpenIPMIc::ipmi_channel_info_t_get_session_support;
*get_vendor_id = *OpenIPMIc::ipmi_channel_info_t_get_vendor_id;
*get_aux_info = *OpenIPMIc::ipmi_channel_info_t_get_aux_info;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_channel_access_t ##############

package OpenIPMI::ipmi_channel_access_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_channel_access_t($self);
        delete $OWNER{$self};
    }
}

*copy = *OpenIPMIc::ipmi_channel_access_t_copy;
*get_channel = *OpenIPMIc::ipmi_channel_access_t_get_channel;
*get_alerting_enabled = *OpenIPMIc::ipmi_channel_access_t_get_alerting_enabled;
*set_alerting_enabled = *OpenIPMIc::ipmi_channel_access_t_set_alerting_enabled;
*get_per_msg_auth = *OpenIPMIc::ipmi_channel_access_t_get_per_msg_auth;
*set_per_msg_auth = *OpenIPMIc::ipmi_channel_access_t_set_per_msg_auth;
*get_user_auth = *OpenIPMIc::ipmi_channel_access_t_get_user_auth;
*set_user_auth = *OpenIPMIc::ipmi_channel_access_t_set_user_auth;
*get_access_mode = *OpenIPMIc::ipmi_channel_access_t_get_access_mode;
*set_access_mode = *OpenIPMIc::ipmi_channel_access_t_set_access_mode;
*get_privilege_limit = *OpenIPMIc::ipmi_channel_access_t_get_privilege_limit;
*set_privilege_limit = *OpenIPMIc::ipmi_channel_access_t_set_privilege_limit;
*setall = *OpenIPMIc::ipmi_channel_access_t_setall;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_user_t ##############

package OpenIPMI::ipmi_user_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_user_t($self);
        delete $OWNER{$self};
    }
}

*copy = *OpenIPMIc::ipmi_user_t_copy;
*get_channel = *OpenIPMIc::ipmi_user_t_get_channel;
*get_num = *OpenIPMIc::ipmi_user_t_get_num;
*set_num = *OpenIPMIc::ipmi_user_t_set_num;
*get_name = *OpenIPMIc::ipmi_user_t_get_name;
*set_name = *OpenIPMIc::ipmi_user_t_set_name;
*set_password = *OpenIPMIc::ipmi_user_t_set_password;
*set_password2 = *OpenIPMIc::ipmi_user_t_set_password2;
*set_password_auto = *OpenIPMIc::ipmi_user_t_set_password_auto;
*get_enable = *OpenIPMIc::ipmi_user_t_get_enable;
*set_enable = *OpenIPMIc::ipmi_user_t_set_enable;
*get_link_auth_enabled = *OpenIPMIc::ipmi_user_t_get_link_auth_enabled;
*set_link_auth_enabled = *OpenIPMIc::ipmi_user_t_set_link_auth_enabled;
*get_msg_auth_enabled = *OpenIPMIc::ipmi_user_t_get_msg_auth_enabled;
*set_msg_auth_enabled = *OpenIPMIc::ipmi_user_t_set_msg_auth_enabled;
*get_access_cb_only = *OpenIPMIc::ipmi_user_t_get_access_cb_only;
*set_access_cb_only = *OpenIPMIc::ipmi_user_t_set_access_cb_only;
*get_privilege_limit = *OpenIPMIc::ipmi_user_t_get_privilege_limit;
*set_privilege_limit = *OpenIPMIc::ipmi_user_t_set_privilege_limit;
*get_session_limit = *OpenIPMIc::ipmi_user_t_get_session_limit;
*set_session_limit = *OpenIPMIc::ipmi_user_t_set_session_limit;
*set_all = *OpenIPMIc::ipmi_user_t_set_all;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_lanparm_t ##############

package OpenIPMI::ipmi_lanparm_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_lanparm_t($self);
        delete $OWNER{$self};
    }
}

*get_mc_id = *OpenIPMIc::ipmi_lanparm_t_get_mc_id;
*get_channel = *OpenIPMIc::ipmi_lanparm_t_get_channel;
*get_parm = *OpenIPMIc::ipmi_lanparm_t_get_parm;
*set_parm = *OpenIPMIc::ipmi_lanparm_t_set_parm;
*set_parm_array = *OpenIPMIc::ipmi_lanparm_t_set_parm_array;
*get_config = *OpenIPMIc::ipmi_lanparm_t_get_config;
*set_config = *OpenIPMIc::ipmi_lanparm_t_set_config;
*clear_lock = *OpenIPMIc::ipmi_lanparm_t_clear_lock;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_lan_config_t ##############

package OpenIPMI::ipmi_lan_config_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_lan_config_t($self);
        delete $OWNER{$self};
    }
}

*get_val = *OpenIPMIc::ipmi_lan_config_t_get_val;
*set_val = *OpenIPMIc::ipmi_lan_config_t_set_val;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_pef_t ##############

package OpenIPMI::ipmi_pef_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_pef_t($self);
        delete $OWNER{$self};
    }
}

*get_mc_id = *OpenIPMIc::ipmi_pef_t_get_mc_id;
*get_parm = *OpenIPMIc::ipmi_pef_t_get_parm;
*set_parm = *OpenIPMIc::ipmi_pef_t_set_parm;
*set_parm_array = *OpenIPMIc::ipmi_pef_t_set_parm_array;
*get_config = *OpenIPMIc::ipmi_pef_t_get_config;
*set_config = *OpenIPMIc::ipmi_pef_t_set_config;
*clear_lock = *OpenIPMIc::ipmi_pef_t_clear_lock;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_pef_config_t ##############

package OpenIPMI::ipmi_pef_config_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_pef_config_t($self);
        delete $OWNER{$self};
    }
}

*get_val = *OpenIPMIc::ipmi_pef_config_t_get_val;
*set_val = *OpenIPMIc::ipmi_pef_config_t_set_val;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_pet_t ##############

package OpenIPMI::ipmi_pet_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_pet_t($self);
        delete $OWNER{$self};
    }
}

*get_mc_id = *OpenIPMIc::ipmi_pet_t_get_mc_id;
*get_channel = *OpenIPMIc::ipmi_pet_t_get_channel;
*get_ip_addr = *OpenIPMIc::ipmi_pet_t_get_ip_addr;
*get_mac_addr = *OpenIPMIc::ipmi_pet_t_get_mac_addr;
*get_eft_sel = *OpenIPMIc::ipmi_pet_t_get_eft_sel;
*get_policy_num = *OpenIPMIc::ipmi_pet_t_get_policy_num;
*get_apt_sel = *OpenIPMIc::ipmi_pet_t_get_apt_sel;
*get_lan_dest_sel = *OpenIPMIc::ipmi_pet_t_get_lan_dest_sel;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_cmdlang_t ##############

package OpenIPMI::ipmi_cmdlang_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_cmdlang_t($self);
        delete $OWNER{$self};
    }
}

*handle = *OpenIPMIc::ipmi_cmdlang_t_handle;
*is_help = *OpenIPMIc::ipmi_cmdlang_t_is_help;
*get_err = *OpenIPMIc::ipmi_cmdlang_t_get_err;
*get_errstr = *OpenIPMIc::ipmi_cmdlang_t_get_errstr;
*get_objstr = *OpenIPMIc::ipmi_cmdlang_t_get_objstr;
*get_location = *OpenIPMIc::ipmi_cmdlang_t_get_location;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_cmdlang_event_t ##############

package OpenIPMI::ipmi_cmdlang_event_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_cmdlang_event_t($self);
        delete $OWNER{$self};
    }
}

*restart = *OpenIPMIc::ipmi_cmdlang_event_t_restart;
*next_field = *OpenIPMIc::ipmi_cmdlang_event_t_next_field;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_sol_conn_t ##############

package OpenIPMI::ipmi_sol_conn_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_sol_conn_t($self);
        delete $OWNER{$self};
    }
}

*set_ACK_timeout = *OpenIPMIc::ipmi_sol_conn_t_set_ACK_timeout;
*get_ACK_timeout = *OpenIPMIc::ipmi_sol_conn_t_get_ACK_timeout;
*set_ACK_retries = *OpenIPMIc::ipmi_sol_conn_t_set_ACK_retries;
*get_ACK_retries = *OpenIPMIc::ipmi_sol_conn_t_get_ACK_retries;
*set_use_authentication = *OpenIPMIc::ipmi_sol_conn_t_set_use_authentication;
*get_use_authentication = *OpenIPMIc::ipmi_sol_conn_t_get_use_authentication;
*set_use_encryption = *OpenIPMIc::ipmi_sol_conn_t_set_use_encryption;
*get_use_encryption = *OpenIPMIc::ipmi_sol_conn_t_get_use_encryption;
*set_shared_serial_alert_behavior = *OpenIPMIc::ipmi_sol_conn_t_set_shared_serial_alert_behavior;
*get_shared_serial_alert_behavior = *OpenIPMIc::ipmi_sol_conn_t_get_shared_serial_alert_behavior;
*set_deassert_CTS_DCD_DSR_on_connect = *OpenIPMIc::ipmi_sol_conn_t_set_deassert_CTS_DCD_DSR_on_connect;
*get_deassert_CTS_DCD_DSR_on_connect = *OpenIPMIc::ipmi_sol_conn_t_get_deassert_CTS_DCD_DSR_on_connect;
*set_bit_rate = *OpenIPMIc::ipmi_sol_conn_t_set_bit_rate;
*get_bit_rate = *OpenIPMIc::ipmi_sol_conn_t_get_bit_rate;
*open = *OpenIPMIc::ipmi_sol_conn_t_open;
*close = *OpenIPMIc::ipmi_sol_conn_t_close;
*force_close = *OpenIPMIc::ipmi_sol_conn_t_force_close;
*write = *OpenIPMIc::ipmi_sol_conn_t_write;
*release_nack = *OpenIPMIc::ipmi_sol_conn_t_release_nack;
*send_break = *OpenIPMIc::ipmi_sol_conn_t_send_break;
*set_CTS_assertable = *OpenIPMIc::ipmi_sol_conn_t_set_CTS_assertable;
*set_DCD_DSR_asserted = *OpenIPMIc::ipmi_sol_conn_t_set_DCD_DSR_asserted;
*set_RI_asserted = *OpenIPMIc::ipmi_sol_conn_t_set_RI_asserted;
*flush = *OpenIPMIc::ipmi_sol_conn_t_flush;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_sol_config_t ##############

package OpenIPMI::ipmi_sol_config_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_sol_config_t($self);
        delete $OWNER{$self};
    }
}

*get_val = *OpenIPMIc::ipmi_sol_config_t_get_val;
*set_val = *OpenIPMIc::ipmi_sol_config_t_set_val;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : OpenIPMI::ipmi_solparm_t ##############

package OpenIPMI::ipmi_solparm_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( OpenIPMI );
%OWNER = ();
%ITERATORS = ();
sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        OpenIPMIc::delete_ipmi_solparm_t($self);
        delete $OWNER{$self};
    }
}

*get_mc_id = *OpenIPMIc::ipmi_solparm_t_get_mc_id;
*get_channel = *OpenIPMIc::ipmi_solparm_t_get_channel;
*get_parm = *OpenIPMIc::ipmi_solparm_t_get_parm;
*set_parm = *OpenIPMIc::ipmi_solparm_t_set_parm;
*set_parm_array = *OpenIPMIc::ipmi_solparm_t_set_parm_array;
*get_config = *OpenIPMIc::ipmi_solparm_t_get_config;
*set_config = *OpenIPMIc::ipmi_solparm_t_set_config;
*clear_lock = *OpenIPMIc::ipmi_solparm_t_clear_lock;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


# ------- VARIABLE STUBS --------

package OpenIPMI;

*FRU_INTERNAL_USE_AREA = *OpenIPMIc::FRU_INTERNAL_USE_AREA;
*FRU_CHASSIS_INFO_AREA = *OpenIPMIc::FRU_CHASSIS_INFO_AREA;
*FRU_BOARD_INFO_AREA = *OpenIPMIc::FRU_BOARD_INFO_AREA;
*FRU_PRODUCT_INFO_AREA = *OpenIPMIc::FRU_PRODUCT_INFO_AREA;
*FRU_MULTI_RECORD_AREA = *OpenIPMIc::FRU_MULTI_RECORD_AREA;
*MC_RESET_COLD = *OpenIPMIc::MC_RESET_COLD;
*MC_RESET_WARM = *OpenIPMIc::MC_RESET_WARM;
*MAX_USED_CHANNELS = *OpenIPMIc::MAX_USED_CHANNELS;
*SENSOR_TYPE_TEMPERATURE = *OpenIPMIc::SENSOR_TYPE_TEMPERATURE;
*SENSOR_TYPE_VOLTAGE = *OpenIPMIc::SENSOR_TYPE_VOLTAGE;
*SENSOR_TYPE_CURRENT = *OpenIPMIc::SENSOR_TYPE_CURRENT;
*SENSOR_TYPE_FAN = *OpenIPMIc::SENSOR_TYPE_FAN;
*SENSOR_TYPE_PHYSICAL_SECURITY = *OpenIPMIc::SENSOR_TYPE_PHYSICAL_SECURITY;
*SENSOR_TYPE_PLATFORM_SECURITY = *OpenIPMIc::SENSOR_TYPE_PLATFORM_SECURITY;
*SENSOR_TYPE_PROCESSOR = *OpenIPMIc::SENSOR_TYPE_PROCESSOR;
*SENSOR_TYPE_POWER_SUPPLY = *OpenIPMIc::SENSOR_TYPE_POWER_SUPPLY;
*SENSOR_TYPE_POWER_UNIT = *OpenIPMIc::SENSOR_TYPE_POWER_UNIT;
*SENSOR_TYPE_COOLING_DEVICE = *OpenIPMIc::SENSOR_TYPE_COOLING_DEVICE;
*SENSOR_TYPE_OTHER_UNITS_BASED_SENSOR = *OpenIPMIc::SENSOR_TYPE_OTHER_UNITS_BASED_SENSOR;
*SENSOR_TYPE_MEMORY = *OpenIPMIc::SENSOR_TYPE_MEMORY;
*SENSOR_TYPE_DRIVE_SLOT = *OpenIPMIc::SENSOR_TYPE_DRIVE_SLOT;
*SENSOR_TYPE_POWER_MEMORY_RESIZE = *OpenIPMIc::SENSOR_TYPE_POWER_MEMORY_RESIZE;
*SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS = *OpenIPMIc::SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS;
*SENSOR_TYPE_EVENT_LOGGING_DISABLED = *OpenIPMIc::SENSOR_TYPE_EVENT_LOGGING_DISABLED;
*SENSOR_TYPE_WATCHDOG_1 = *OpenIPMIc::SENSOR_TYPE_WATCHDOG_1;
*SENSOR_TYPE_SYSTEM_EVENT = *OpenIPMIc::SENSOR_TYPE_SYSTEM_EVENT;
*SENSOR_TYPE_CRITICAL_INTERRUPT = *OpenIPMIc::SENSOR_TYPE_CRITICAL_INTERRUPT;
*SENSOR_TYPE_BUTTON = *OpenIPMIc::SENSOR_TYPE_BUTTON;
*SENSOR_TYPE_MODULE_BOARD = *OpenIPMIc::SENSOR_TYPE_MODULE_BOARD;
*SENSOR_TYPE_MICROCONTROLLER_COPROCESSOR = *OpenIPMIc::SENSOR_TYPE_MICROCONTROLLER_COPROCESSOR;
*SENSOR_TYPE_ADD_IN_CARD = *OpenIPMIc::SENSOR_TYPE_ADD_IN_CARD;
*SENSOR_TYPE_CHASSIS = *OpenIPMIc::SENSOR_TYPE_CHASSIS;
*SENSOR_TYPE_CHIP_SET = *OpenIPMIc::SENSOR_TYPE_CHIP_SET;
*SENSOR_TYPE_OTHER_FRU = *OpenIPMIc::SENSOR_TYPE_OTHER_FRU;
*SENSOR_TYPE_CABLE_INTERCONNECT = *OpenIPMIc::SENSOR_TYPE_CABLE_INTERCONNECT;
*SENSOR_TYPE_TERMINATOR = *OpenIPMIc::SENSOR_TYPE_TERMINATOR;
*SENSOR_TYPE_SYSTEM_BOOT_INITIATED = *OpenIPMIc::SENSOR_TYPE_SYSTEM_BOOT_INITIATED;
*SENSOR_TYPE_BOOT_ERROR = *OpenIPMIc::SENSOR_TYPE_BOOT_ERROR;
*SENSOR_TYPE_OS_BOOT = *OpenIPMIc::SENSOR_TYPE_OS_BOOT;
*SENSOR_TYPE_OS_CRITICAL_STOP = *OpenIPMIc::SENSOR_TYPE_OS_CRITICAL_STOP;
*SENSOR_TYPE_SLOT_CONNECTOR = *OpenIPMIc::SENSOR_TYPE_SLOT_CONNECTOR;
*SENSOR_TYPE_SYSTEM_ACPI_POWER_STATE = *OpenIPMIc::SENSOR_TYPE_SYSTEM_ACPI_POWER_STATE;
*SENSOR_TYPE_WATCHDOG_2 = *OpenIPMIc::SENSOR_TYPE_WATCHDOG_2;
*SENSOR_TYPE_PLATFORM_ALERT = *OpenIPMIc::SENSOR_TYPE_PLATFORM_ALERT;
*SENSOR_TYPE_ENTITY_PRESENCE = *OpenIPMIc::SENSOR_TYPE_ENTITY_PRESENCE;
*SENSOR_TYPE_MONITOR_ASIC_IC = *OpenIPMIc::SENSOR_TYPE_MONITOR_ASIC_IC;
*SENSOR_TYPE_LAN = *OpenIPMIc::SENSOR_TYPE_LAN;
*SENSOR_TYPE_MANAGEMENT_SUBSYSTEM_HEALTH = *OpenIPMIc::SENSOR_TYPE_MANAGEMENT_SUBSYSTEM_HEALTH;
*SENSOR_TYPE_BATTERY = *OpenIPMIc::SENSOR_TYPE_BATTERY;
*EVENT_READING_TYPE_THRESHOLD = *OpenIPMIc::EVENT_READING_TYPE_THRESHOLD;
*EVENT_READING_TYPE_DISCRETE_USAGE = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_USAGE;
*EVENT_READING_TYPE_DISCRETE_STATE = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_STATE;
*EVENT_READING_TYPE_DISCRETE_PREDICTIVE_FAILURE = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_PREDICTIVE_FAILURE;
*EVENT_READING_TYPE_DISCRETE_LIMIT_EXCEEDED = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_LIMIT_EXCEEDED;
*EVENT_READING_TYPE_DISCRETE_PERFORMANCE_MET = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_PERFORMANCE_MET;
*EVENT_READING_TYPE_DISCRETE_SEVERITY = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_SEVERITY;
*EVENT_READING_TYPE_DISCRETE_DEVICE_PRESENCE = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_DEVICE_PRESENCE;
*EVENT_READING_TYPE_DISCRETE_DEVICE_ENABLE = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_DEVICE_ENABLE;
*EVENT_READING_TYPE_DISCRETE_AVAILABILITY = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_AVAILABILITY;
*EVENT_READING_TYPE_DISCRETE_REDUNDANCY = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_REDUNDANCY;
*EVENT_READING_TYPE_DISCRETE_ACPI_POWER = *OpenIPMIc::EVENT_READING_TYPE_DISCRETE_ACPI_POWER;
*EVENT_READING_TYPE_SENSOR_SPECIFIC = *OpenIPMIc::EVENT_READING_TYPE_SENSOR_SPECIFIC;
*RATE_UNIT_NONE = *OpenIPMIc::RATE_UNIT_NONE;
*RATE_UNIT_PER_US = *OpenIPMIc::RATE_UNIT_PER_US;
*RATE_UNIT_PER_MS = *OpenIPMIc::RATE_UNIT_PER_MS;
*RATE_UNIT_PER_SEC = *OpenIPMIc::RATE_UNIT_PER_SEC;
*RATE_UNIT_MIN = *OpenIPMIc::RATE_UNIT_MIN;
*RATE_UNIT_HOUR = *OpenIPMIc::RATE_UNIT_HOUR;
*RATE_UNIT_DAY = *OpenIPMIc::RATE_UNIT_DAY;
*UNIT_TYPE_UNSPECIFIED = *OpenIPMIc::UNIT_TYPE_UNSPECIFIED;
*UNIT_TYPE_DEGREES_C = *OpenIPMIc::UNIT_TYPE_DEGREES_C;
*UNIT_TYPE_DEGREES_F = *OpenIPMIc::UNIT_TYPE_DEGREES_F;
*UNIT_TYPE_DEGREES_K = *OpenIPMIc::UNIT_TYPE_DEGREES_K;
*UNIT_TYPE_VOLTS = *OpenIPMIc::UNIT_TYPE_VOLTS;
*UNIT_TYPE_AMPS = *OpenIPMIc::UNIT_TYPE_AMPS;
*UNIT_TYPE_WATTS = *OpenIPMIc::UNIT_TYPE_WATTS;
*UNIT_TYPE_JOULES = *OpenIPMIc::UNIT_TYPE_JOULES;
*UNIT_TYPE_COULOMBS = *OpenIPMIc::UNIT_TYPE_COULOMBS;
*UNIT_TYPE_VA = *OpenIPMIc::UNIT_TYPE_VA;
*UNIT_TYPE_NITS = *OpenIPMIc::UNIT_TYPE_NITS;
*UNIT_TYPE_LUMENS = *OpenIPMIc::UNIT_TYPE_LUMENS;
*UNIT_TYPE_LUX = *OpenIPMIc::UNIT_TYPE_LUX;
*UNIT_TYPE_CANDELA = *OpenIPMIc::UNIT_TYPE_CANDELA;
*UNIT_TYPE_KPA = *OpenIPMIc::UNIT_TYPE_KPA;
*UNIT_TYPE_PSI = *OpenIPMIc::UNIT_TYPE_PSI;
*UNIT_TYPE_NEWTONS = *OpenIPMIc::UNIT_TYPE_NEWTONS;
*UNIT_TYPE_CFM = *OpenIPMIc::UNIT_TYPE_CFM;
*UNIT_TYPE_RPM = *OpenIPMIc::UNIT_TYPE_RPM;
*UNIT_TYPE_HZ = *OpenIPMIc::UNIT_TYPE_HZ;
*UNIT_TYPE_USECONDS = *OpenIPMIc::UNIT_TYPE_USECONDS;
*UNIT_TYPE_MSECONDS = *OpenIPMIc::UNIT_TYPE_MSECONDS;
*UNIT_TYPE_SECONDS = *OpenIPMIc::UNIT_TYPE_SECONDS;
*UNIT_TYPE_MINUTE = *OpenIPMIc::UNIT_TYPE_MINUTE;
*UNIT_TYPE_HOUR = *OpenIPMIc::UNIT_TYPE_HOUR;
*UNIT_TYPE_DAY = *OpenIPMIc::UNIT_TYPE_DAY;
*UNIT_TYPE_WEEK = *OpenIPMIc::UNIT_TYPE_WEEK;
*UNIT_TYPE_MIL = *OpenIPMIc::UNIT_TYPE_MIL;
*UNIT_TYPE_INCHES = *OpenIPMIc::UNIT_TYPE_INCHES;
*UNIT_TYPE_FEET = *OpenIPMIc::UNIT_TYPE_FEET;
*UNIT_TYPE_CUBIC_INCHS = *OpenIPMIc::UNIT_TYPE_CUBIC_INCHS;
*UNIT_TYPE_CUBIC_FEET = *OpenIPMIc::UNIT_TYPE_CUBIC_FEET;
*UNIT_TYPE_MILLIMETERS = *OpenIPMIc::UNIT_TYPE_MILLIMETERS;
*UNIT_TYPE_CENTIMETERS = *OpenIPMIc::UNIT_TYPE_CENTIMETERS;
*UNIT_TYPE_METERS = *OpenIPMIc::UNIT_TYPE_METERS;
*UNIT_TYPE_CUBIC_CENTIMETERS = *OpenIPMIc::UNIT_TYPE_CUBIC_CENTIMETERS;
*UNIT_TYPE_CUBIC_METERS = *OpenIPMIc::UNIT_TYPE_CUBIC_METERS;
*UNIT_TYPE_LITERS = *OpenIPMIc::UNIT_TYPE_LITERS;
*UNIT_TYPE_FL_OZ = *OpenIPMIc::UNIT_TYPE_FL_OZ;
*UNIT_TYPE_RADIANS = *OpenIPMIc::UNIT_TYPE_RADIANS;
*UNIT_TYPE_SERADIANS = *OpenIPMIc::UNIT_TYPE_SERADIANS;
*UNIT_TYPE_REVOLUTIONS = *OpenIPMIc::UNIT_TYPE_REVOLUTIONS;
*UNIT_TYPE_CYCLES = *OpenIPMIc::UNIT_TYPE_CYCLES;
*UNIT_TYPE_GRAVITIES = *OpenIPMIc::UNIT_TYPE_GRAVITIES;
*UNIT_TYPE_OUNCES = *OpenIPMIc::UNIT_TYPE_OUNCES;
*UNIT_TYPE_POUNDS = *OpenIPMIc::UNIT_TYPE_POUNDS;
*UNIT_TYPE_FOOT_POUNDS = *OpenIPMIc::UNIT_TYPE_FOOT_POUNDS;
*UNIT_TYPE_OUNCE_INCHES = *OpenIPMIc::UNIT_TYPE_OUNCE_INCHES;
*UNIT_TYPE_GAUSS = *OpenIPMIc::UNIT_TYPE_GAUSS;
*UNIT_TYPE_GILBERTS = *OpenIPMIc::UNIT_TYPE_GILBERTS;
*UNIT_TYPE_HENRIES = *OpenIPMIc::UNIT_TYPE_HENRIES;
*UNIT_TYPE_MHENRIES = *OpenIPMIc::UNIT_TYPE_MHENRIES;
*UNIT_TYPE_FARADS = *OpenIPMIc::UNIT_TYPE_FARADS;
*UNIT_TYPE_UFARADS = *OpenIPMIc::UNIT_TYPE_UFARADS;
*UNIT_TYPE_OHMS = *OpenIPMIc::UNIT_TYPE_OHMS;
*UNIT_TYPE_SIEMENS = *OpenIPMIc::UNIT_TYPE_SIEMENS;
*UNIT_TYPE_MOLES = *OpenIPMIc::UNIT_TYPE_MOLES;
*UNIT_TYPE_BECQUERELS = *OpenIPMIc::UNIT_TYPE_BECQUERELS;
*UNIT_TYPE_PPM = *OpenIPMIc::UNIT_TYPE_PPM;
*UNIT_TYPE_reserved1 = *OpenIPMIc::UNIT_TYPE_reserved1;
*UNIT_TYPE_DECIBELS = *OpenIPMIc::UNIT_TYPE_DECIBELS;
*UNIT_TYPE_DbA = *OpenIPMIc::UNIT_TYPE_DbA;
*UNIT_TYPE_DbC = *OpenIPMIc::UNIT_TYPE_DbC;
*UNIT_TYPE_GRAYS = *OpenIPMIc::UNIT_TYPE_GRAYS;
*UNIT_TYPE_SIEVERTS = *OpenIPMIc::UNIT_TYPE_SIEVERTS;
*UNIT_TYPE_COLOR_TEMP_DEG_K = *OpenIPMIc::UNIT_TYPE_COLOR_TEMP_DEG_K;
*UNIT_TYPE_BITS = *OpenIPMIc::UNIT_TYPE_BITS;
*UNIT_TYPE_KBITS = *OpenIPMIc::UNIT_TYPE_KBITS;
*UNIT_TYPE_MBITS = *OpenIPMIc::UNIT_TYPE_MBITS;
*UNIT_TYPE_GBITS = *OpenIPMIc::UNIT_TYPE_GBITS;
*UNIT_TYPE_BYTES = *OpenIPMIc::UNIT_TYPE_BYTES;
*UNIT_TYPE_KBYTES = *OpenIPMIc::UNIT_TYPE_KBYTES;
*UNIT_TYPE_MBYTES = *OpenIPMIc::UNIT_TYPE_MBYTES;
*UNIT_TYPE_GBYTES = *OpenIPMIc::UNIT_TYPE_GBYTES;
*UNIT_TYPE_WORDS = *OpenIPMIc::UNIT_TYPE_WORDS;
*UNIT_TYPE_DWORDS = *OpenIPMIc::UNIT_TYPE_DWORDS;
*UNIT_TYPE_QWORDS = *OpenIPMIc::UNIT_TYPE_QWORDS;
*UNIT_TYPE_LINES = *OpenIPMIc::UNIT_TYPE_LINES;
*UNIT_TYPE_HITS = *OpenIPMIc::UNIT_TYPE_HITS;
*UNIT_TYPE_MISSES = *OpenIPMIc::UNIT_TYPE_MISSES;
*UNIT_TYPE_RETRIES = *OpenIPMIc::UNIT_TYPE_RETRIES;
*UNIT_TYPE_RESETS = *OpenIPMIc::UNIT_TYPE_RESETS;
*UNIT_TYPE_OVERRUNS = *OpenIPMIc::UNIT_TYPE_OVERRUNS;
*UNIT_TYPE_UNDERRUNS = *OpenIPMIc::UNIT_TYPE_UNDERRUNS;
*UNIT_TYPE_COLLISIONS = *OpenIPMIc::UNIT_TYPE_COLLISIONS;
*UNIT_TYPE_PACKETS = *OpenIPMIc::UNIT_TYPE_PACKETS;
*UNIT_TYPE_MESSAGES = *OpenIPMIc::UNIT_TYPE_MESSAGES;
*UNIT_TYPE_CHARACTERS = *OpenIPMIc::UNIT_TYPE_CHARACTERS;
*UNIT_TYPE_ERRORS = *OpenIPMIc::UNIT_TYPE_ERRORS;
*UNIT_TYPE_CORRECTABLE_ERRORS = *OpenIPMIc::UNIT_TYPE_CORRECTABLE_ERRORS;
*UNIT_TYPE_UNCORRECTABLE_ERRORS = *OpenIPMIc::UNIT_TYPE_UNCORRECTABLE_ERRORS;
*UNIT_TYPE_FATAL_ERRORS = *OpenIPMIc::UNIT_TYPE_FATAL_ERRORS;
*UNIT_TYPE_GRAMS = *OpenIPMIc::UNIT_TYPE_GRAMS;
*MODIFIER_UNIT_NONE = *OpenIPMIc::MODIFIER_UNIT_NONE;
*MODIFIER_UNIT_BASE_DIV_MOD = *OpenIPMIc::MODIFIER_UNIT_BASE_DIV_MOD;
*MODIFIER_UNIT_BASE_MULT_MOD = *OpenIPMIc::MODIFIER_UNIT_BASE_MULT_MOD;
*THRESHOLD_ACCESS_SUPPORT_NONE = *OpenIPMIc::THRESHOLD_ACCESS_SUPPORT_NONE;
*THRESHOLD_ACCESS_SUPPORT_READABLE = *OpenIPMIc::THRESHOLD_ACCESS_SUPPORT_READABLE;
*THRESHOLD_ACCESS_SUPPORT_SETTABLE = *OpenIPMIc::THRESHOLD_ACCESS_SUPPORT_SETTABLE;
*THRESHOLD_ACCESS_SUPPORT_FIXED = *OpenIPMIc::THRESHOLD_ACCESS_SUPPORT_FIXED;
*HYSTERESIS_SUPPORT_NONE = *OpenIPMIc::HYSTERESIS_SUPPORT_NONE;
*HYSTERESIS_SUPPORT_READABLE = *OpenIPMIc::HYSTERESIS_SUPPORT_READABLE;
*HYSTERESIS_SUPPORT_SETTABLE = *OpenIPMIc::HYSTERESIS_SUPPORT_SETTABLE;
*HYSTERESIS_SUPPORT_FIXED = *OpenIPMIc::HYSTERESIS_SUPPORT_FIXED;
*EVENT_SUPPORT_PER_STATE = *OpenIPMIc::EVENT_SUPPORT_PER_STATE;
*EVENT_SUPPORT_ENTIRE_SENSOR = *OpenIPMIc::EVENT_SUPPORT_ENTIRE_SENSOR;
*EVENT_SUPPORT_GLOBAL_ENABLE = *OpenIPMIc::EVENT_SUPPORT_GLOBAL_ENABLE;
*EVENT_SUPPORT_GLOBAL_DISABLE = *OpenIPMIc::EVENT_SUPPORT_GLOBAL_DISABLE;
*EVENT_SUPPORT_NONE = *OpenIPMIc::EVENT_SUPPORT_NONE;
*SENSOR_DIRECTION_UNSPECIFIED = *OpenIPMIc::SENSOR_DIRECTION_UNSPECIFIED;
*SENSOR_DIRECTION_INPUT = *OpenIPMIc::SENSOR_DIRECTION_INPUT;
*SENSOR_DIRECTION_OUTPUT = *OpenIPMIc::SENSOR_DIRECTION_OUTPUT;
*CONTROL_LIGHT = *OpenIPMIc::CONTROL_LIGHT;
*CONTROL_RELAY = *OpenIPMIc::CONTROL_RELAY;
*CONTROL_DISPLAY = *OpenIPMIc::CONTROL_DISPLAY;
*CONTROL_ALARM = *OpenIPMIc::CONTROL_ALARM;
*CONTROL_RESET = *OpenIPMIc::CONTROL_RESET;
*CONTROL_POWER = *OpenIPMIc::CONTROL_POWER;
*CONTROL_FAN_SPEED = *OpenIPMIc::CONTROL_FAN_SPEED;
*CONTROL_IDENTIFIER = *OpenIPMIc::CONTROL_IDENTIFIER;
*CONTROL_ONE_SHOT_RESET = *OpenIPMIc::CONTROL_ONE_SHOT_RESET;
*CONTROL_OUTPUT = *OpenIPMIc::CONTROL_OUTPUT;
*CONTROL_ONE_SHOT_OUTPUT = *OpenIPMIc::CONTROL_ONE_SHOT_OUTPUT;
*CONTROL_COLOR_BLACK = *OpenIPMIc::CONTROL_COLOR_BLACK;
*CONTROL_COLOR_WHITE = *OpenIPMIc::CONTROL_COLOR_WHITE;
*CONTROL_COLOR_RED = *OpenIPMIc::CONTROL_COLOR_RED;
*CONTROL_COLOR_GREEN = *OpenIPMIc::CONTROL_COLOR_GREEN;
*CONTROL_COLOR_BLUE = *OpenIPMIc::CONTROL_COLOR_BLUE;
*CONTROL_COLOR_YELLOW = *OpenIPMIc::CONTROL_COLOR_YELLOW;
*CONTROL_COLOR_ORANGE = *OpenIPMIc::CONTROL_COLOR_ORANGE;
*CONTROL_NUM_COLORS = *OpenIPMIc::CONTROL_NUM_COLORS;
*CHANNEL_MEDIUM_IPMB = *OpenIPMIc::CHANNEL_MEDIUM_IPMB;
*CHANNEL_MEDIUM_ICMB_V10 = *OpenIPMIc::CHANNEL_MEDIUM_ICMB_V10;
*CHANNEL_MEDIUM_ICMB_V09 = *OpenIPMIc::CHANNEL_MEDIUM_ICMB_V09;
*CHANNEL_MEDIUM_8023_LAN = *OpenIPMIc::CHANNEL_MEDIUM_8023_LAN;
*CHANNEL_MEDIUM_RS232 = *OpenIPMIc::CHANNEL_MEDIUM_RS232;
*CHANNEL_MEDIUM_OTHER_LAN = *OpenIPMIc::CHANNEL_MEDIUM_OTHER_LAN;
*CHANNEL_MEDIUM_PCI_SMBUS = *OpenIPMIc::CHANNEL_MEDIUM_PCI_SMBUS;
*CHANNEL_MEDIUM_SMBUS_v1 = *OpenIPMIc::CHANNEL_MEDIUM_SMBUS_v1;
*CHANNEL_MEDIUM_SMBUS_v2 = *OpenIPMIc::CHANNEL_MEDIUM_SMBUS_v2;
*CHANNEL_MEDIUM_USB_v1 = *OpenIPMIc::CHANNEL_MEDIUM_USB_v1;
*CHANNEL_MEDIUM_USB_v2 = *OpenIPMIc::CHANNEL_MEDIUM_USB_v2;
*CHANNEL_MEDIUM_SYS_INTF = *OpenIPMIc::CHANNEL_MEDIUM_SYS_INTF;
*CHANNEL_PROTOCOL_IPMB = *OpenIPMIc::CHANNEL_PROTOCOL_IPMB;
*CHANNEL_PROTOCOL_ICMB = *OpenIPMIc::CHANNEL_PROTOCOL_ICMB;
*CHANNEL_PROTOCOL_SMBus = *OpenIPMIc::CHANNEL_PROTOCOL_SMBus;
*CHANNEL_PROTOCOL_KCS = *OpenIPMIc::CHANNEL_PROTOCOL_KCS;
*CHANNEL_PROTOCOL_SMIC = *OpenIPMIc::CHANNEL_PROTOCOL_SMIC;
*CHANNEL_PROTOCOL_BT_v10 = *OpenIPMIc::CHANNEL_PROTOCOL_BT_v10;
*CHANNEL_PROTOCOL_BT_v15 = *OpenIPMIc::CHANNEL_PROTOCOL_BT_v15;
*CHANNEL_PROTOCOL_TMODE = *OpenIPMIc::CHANNEL_PROTOCOL_TMODE;
*CHANNEL_SESSION_LESS = *OpenIPMIc::CHANNEL_SESSION_LESS;
*CHANNEL_SINGLE_SESSION = *OpenIPMIc::CHANNEL_SINGLE_SESSION;
*CHANNEL_MULTI_SESSION = *OpenIPMIc::CHANNEL_MULTI_SESSION;
*CHANNEL_SESSION_BASED = *OpenIPMIc::CHANNEL_SESSION_BASED;
*CHANNEL_ACCESS_MODE_DISABLED = *OpenIPMIc::CHANNEL_ACCESS_MODE_DISABLED;
*CHANNEL_ACCESS_MODE_PRE_BOOT = *OpenIPMIc::CHANNEL_ACCESS_MODE_PRE_BOOT;
*CHANNEL_ACCESS_MODE_ALWAYS = *OpenIPMIc::CHANNEL_ACCESS_MODE_ALWAYS;
*CHANNEL_ACCESS_MODE_SHARED = *OpenIPMIc::CHANNEL_ACCESS_MODE_SHARED;
*PRIVILEGE_CALLBACK = *OpenIPMIc::PRIVILEGE_CALLBACK;
*PRIVILEGE_USER = *OpenIPMIc::PRIVILEGE_USER;
*PRIVILEGE_OPERATOR = *OpenIPMIc::PRIVILEGE_OPERATOR;
*PRIVILEGE_ADMIN = *OpenIPMIc::PRIVILEGE_ADMIN;
*PRIVILEGE_OEM = *OpenIPMIc::PRIVILEGE_OEM;
*LANPARM_SET_IN_PROGRESS = *OpenIPMIc::LANPARM_SET_IN_PROGRESS;
*LANPARM_AUTH_TYPE_SUPPORT = *OpenIPMIc::LANPARM_AUTH_TYPE_SUPPORT;
*LANPARM_AUTH_TYPE_ENABLES = *OpenIPMIc::LANPARM_AUTH_TYPE_ENABLES;
*LANPARM_IP_ADDRESS = *OpenIPMIc::LANPARM_IP_ADDRESS;
*LANPARM_IP_ADDRESS_SRC = *OpenIPMIc::LANPARM_IP_ADDRESS_SRC;
*LANPARM_MAC_ADDRESS = *OpenIPMIc::LANPARM_MAC_ADDRESS;
*LANPARM_SUBNET_MASK = *OpenIPMIc::LANPARM_SUBNET_MASK;
*LANPARM_IPV4_HDR_PARMS = *OpenIPMIc::LANPARM_IPV4_HDR_PARMS;
*LANPARM_PRIMARY_RMCP_PORT = *OpenIPMIc::LANPARM_PRIMARY_RMCP_PORT;
*LANPARM_SECONDARY_RMCP_PORT = *OpenIPMIc::LANPARM_SECONDARY_RMCP_PORT;
*LANPARM_BMC_GENERATED_ARP_CNTL = *OpenIPMIc::LANPARM_BMC_GENERATED_ARP_CNTL;
*LANPARM_GRATUIDOUS_ARP_INTERVAL = *OpenIPMIc::LANPARM_GRATUIDOUS_ARP_INTERVAL;
*LANPARM_DEFAULT_GATEWAY_ADDR = *OpenIPMIc::LANPARM_DEFAULT_GATEWAY_ADDR;
*LANPARM_DEFAULT_GATEWAY_MAC_ADDR = *OpenIPMIc::LANPARM_DEFAULT_GATEWAY_MAC_ADDR;
*LANPARM_BACKUP_GATEWAY_ADDR = *OpenIPMIc::LANPARM_BACKUP_GATEWAY_ADDR;
*LANPARM_BACKUP_GATEWAY_MAC_ADDR = *OpenIPMIc::LANPARM_BACKUP_GATEWAY_MAC_ADDR;
*LANPARM_COMMUNITY_STRING = *OpenIPMIc::LANPARM_COMMUNITY_STRING;
*LANPARM_NUM_DESTINATIONS = *OpenIPMIc::LANPARM_NUM_DESTINATIONS;
*LANPARM_DEST_TYPE = *OpenIPMIc::LANPARM_DEST_TYPE;
*LANPARM_DEST_ADDR = *OpenIPMIc::LANPARM_DEST_ADDR;
*LANPARM_VLAN_ID = *OpenIPMIc::LANPARM_VLAN_ID;
*LANPARM_VLAN_PRIORITY = *OpenIPMIc::LANPARM_VLAN_PRIORITY;
*LANPARM_NUM_CIPHER_SUITE_ENTRIES = *OpenIPMIc::LANPARM_NUM_CIPHER_SUITE_ENTRIES;
*LANPARM_CIPHER_SUITE_ENTRY_SUPPORT = *OpenIPMIc::LANPARM_CIPHER_SUITE_ENTRY_SUPPORT;
*LANPARM_CIPHER_SUITE_ENTRY_PRIV = *OpenIPMIc::LANPARM_CIPHER_SUITE_ENTRY_PRIV;
*LANPARM_DEST_VLAN_TAG = *OpenIPMIc::LANPARM_DEST_VLAN_TAG;
*PEFPARM_SET_IN_PROGRESS = *OpenIPMIc::PEFPARM_SET_IN_PROGRESS;
*PEFPARM_CONTROL = *OpenIPMIc::PEFPARM_CONTROL;
*PEFPARM_ACTION_GLOBAL_CONTROL = *OpenIPMIc::PEFPARM_ACTION_GLOBAL_CONTROL;
*PEFPARM_STARTUP_DELAY = *OpenIPMIc::PEFPARM_STARTUP_DELAY;
*PEFPARM_ALERT_STARTUP_DELAY = *OpenIPMIc::PEFPARM_ALERT_STARTUP_DELAY;
*PEFPARM_NUM_EVENT_FILTERS = *OpenIPMIc::PEFPARM_NUM_EVENT_FILTERS;
*PEFPARM_EVENT_FILTER_TABLE = *OpenIPMIc::PEFPARM_EVENT_FILTER_TABLE;
*PEFPARM_EVENT_FILTER_TABLE_DATA1 = *OpenIPMIc::PEFPARM_EVENT_FILTER_TABLE_DATA1;
*PEFPARM_NUM_ALERT_POLICIES = *OpenIPMIc::PEFPARM_NUM_ALERT_POLICIES;
*PEFPARM_ALERT_POLICY_TABLE = *OpenIPMIc::PEFPARM_ALERT_POLICY_TABLE;
*PEFPARM_SYSTEM_GUID = *OpenIPMIc::PEFPARM_SYSTEM_GUID;
*PEFPARM_NUM_ALERT_STRINGS = *OpenIPMIc::PEFPARM_NUM_ALERT_STRINGS;
*PEFPARM_ALERT_STRING_KEY = *OpenIPMIc::PEFPARM_ALERT_STRING_KEY;
*PEFPARM_ALERT_STRING = *OpenIPMIc::PEFPARM_ALERT_STRING;
*sol_state_closed = *OpenIPMIc::sol_state_closed;
*sol_state_connecting = *OpenIPMIc::sol_state_connecting;
*sol_state_connected = *OpenIPMIc::sol_state_connected;
*sol_state_connected_ctu = *OpenIPMIc::sol_state_connected_ctu;
*sol_state_closing = *OpenIPMIc::sol_state_closing;
*sol_serial_alerts_fail = *OpenIPMIc::sol_serial_alerts_fail;
*sol_serial_alerts_deferred = *OpenIPMIc::sol_serial_alerts_deferred;
*sol_serial_alerts_succeed = *OpenIPMIc::sol_serial_alerts_succeed;
*SOL_BIT_RATE_DEFAULT = *OpenIPMIc::SOL_BIT_RATE_DEFAULT;
*SOL_BIT_RATE_9600 = *OpenIPMIc::SOL_BIT_RATE_9600;
*SOL_BIT_RATE_19200 = *OpenIPMIc::SOL_BIT_RATE_19200;
*SOL_BIT_RATE_38400 = *OpenIPMIc::SOL_BIT_RATE_38400;
*SOL_BIT_RATE_57600 = *OpenIPMIc::SOL_BIT_RATE_57600;
*SOL_BIT_RATE_115200 = *OpenIPMIc::SOL_BIT_RATE_115200;
*SOL_BMC_TRANSMIT_QUEUE = *OpenIPMIc::SOL_BMC_TRANSMIT_QUEUE;
*SOL_BMC_RECEIVE_QUEUE = *OpenIPMIc::SOL_BMC_RECEIVE_QUEUE;
*SOL_MANAGEMENT_CONSOLE_TRANSMIT_QUEUE = *OpenIPMIc::SOL_MANAGEMENT_CONSOLE_TRANSMIT_QUEUE;
*SOL_MANAGEMENT_CONSOLE_RECEIVE_QUEUE = *OpenIPMIc::SOL_MANAGEMENT_CONSOLE_RECEIVE_QUEUE;
*SOL_BMC_QUEUES = *OpenIPMIc::SOL_BMC_QUEUES;
*SOL_MANAGEMENT_CONSOLE_QUEUES = *OpenIPMIc::SOL_MANAGEMENT_CONSOLE_QUEUES;
*SOL_ALL_QUEUES = *OpenIPMIc::SOL_ALL_QUEUES;
*SOLPARM_SET_IN_PROGRESS = *OpenIPMIc::SOLPARM_SET_IN_PROGRESS;
*SOLPARM_ENABLE = *OpenIPMIc::SOLPARM_ENABLE;
*SOLPARM_AUTHENTICATION = *OpenIPMIc::SOLPARM_AUTHENTICATION;
*SOLPARM_CHAR_SETTINGS = *OpenIPMIc::SOLPARM_CHAR_SETTINGS;
*SOLPARM_RETRY = *OpenIPMIc::SOLPARM_RETRY;
*SOLPARM_NONVOLATILE_BITRATE = *OpenIPMIc::SOLPARM_NONVOLATILE_BITRATE;
*SOLPARM_VOLATILE_BITRATE = *OpenIPMIc::SOLPARM_VOLATILE_BITRATE;
*SOLPARM_PAYLOAD_CHANNEL = *OpenIPMIc::SOLPARM_PAYLOAD_CHANNEL;
*SOLPARM_PAYLOAD_PORT_NUMBER = *OpenIPMIc::SOLPARM_PAYLOAD_PORT_NUMBER;
*ebadf = *OpenIPMIc::ebadf;
*einval = *OpenIPMIc::einval;
*e2big = *OpenIPMIc::e2big;
*enomem = *OpenIPMIc::enomem;
*enoent = *OpenIPMIc::enoent;
*ecanceled = *OpenIPMIc::ecanceled;
*enosys = *OpenIPMIc::enosys;
*eexist = *OpenIPMIc::eexist;
*eagain = *OpenIPMIc::eagain;
*eperm = *OpenIPMIc::eperm;
*EVENT_NOT_HANDLED = *OpenIPMIc::EVENT_NOT_HANDLED;
*EVENT_HANDLED = *OpenIPMIc::EVENT_HANDLED;
*EVENT_HANDLED_PASS = *OpenIPMIc::EVENT_HANDLED_PASS;
*TIMEOUT_FOREVER = *OpenIPMIc::TIMEOUT_FOREVER;
*ENTITY_ID_UNSPECIFIED = *OpenIPMIc::ENTITY_ID_UNSPECIFIED;
*ENTITY_ID_OTHER = *OpenIPMIc::ENTITY_ID_OTHER;
*ENTITY_ID_UNKOWN = *OpenIPMIc::ENTITY_ID_UNKOWN;
*ENTITY_ID_PROCESSOR = *OpenIPMIc::ENTITY_ID_PROCESSOR;
*ENTITY_ID_DISK = *OpenIPMIc::ENTITY_ID_DISK;
*ENTITY_ID_PERIPHERAL = *OpenIPMIc::ENTITY_ID_PERIPHERAL;
*ENTITY_ID_SYSTEM_MANAGEMENT_MODULE = *OpenIPMIc::ENTITY_ID_SYSTEM_MANAGEMENT_MODULE;
*ENTITY_ID_SYSTEM_BOARD = *OpenIPMIc::ENTITY_ID_SYSTEM_BOARD;
*ENTITY_ID_MEMORY_MODULE = *OpenIPMIc::ENTITY_ID_MEMORY_MODULE;
*ENTITY_ID_PROCESSOR_MODULE = *OpenIPMIc::ENTITY_ID_PROCESSOR_MODULE;
*ENTITY_ID_POWER_SUPPLY = *OpenIPMIc::ENTITY_ID_POWER_SUPPLY;
*ENTITY_ID_ADD_IN_CARD = *OpenIPMIc::ENTITY_ID_ADD_IN_CARD;
*ENTITY_ID_FRONT_PANEL_BOARD = *OpenIPMIc::ENTITY_ID_FRONT_PANEL_BOARD;
*ENTITY_ID_BACK_PANEL_BOARD = *OpenIPMIc::ENTITY_ID_BACK_PANEL_BOARD;
*ENTITY_ID_POWER_SYSTEM_BOARD = *OpenIPMIc::ENTITY_ID_POWER_SYSTEM_BOARD;
*ENTITY_ID_DRIVE_BACKPLANE = *OpenIPMIc::ENTITY_ID_DRIVE_BACKPLANE;
*ENTITY_ID_SYSTEM_INTERNAL_EXPANSION_BOARD = *OpenIPMIc::ENTITY_ID_SYSTEM_INTERNAL_EXPANSION_BOARD;
*ENTITY_ID_OTHER_SYSTEM_BOARD = *OpenIPMIc::ENTITY_ID_OTHER_SYSTEM_BOARD;
*ENTITY_ID_PROCESSOR_BOARD = *OpenIPMIc::ENTITY_ID_PROCESSOR_BOARD;
*ENTITY_ID_POWER_UNIT = *OpenIPMIc::ENTITY_ID_POWER_UNIT;
*ENTITY_ID_POWER_MODULE = *OpenIPMIc::ENTITY_ID_POWER_MODULE;
*ENTITY_ID_POWER_MANAGEMENT_BOARD = *OpenIPMIc::ENTITY_ID_POWER_MANAGEMENT_BOARD;
*ENTITY_ID_CHASSIS_BACK_PANEL_BOARD = *OpenIPMIc::ENTITY_ID_CHASSIS_BACK_PANEL_BOARD;
*ENTITY_ID_SYSTEM_CHASSIS = *OpenIPMIc::ENTITY_ID_SYSTEM_CHASSIS;
*ENTITY_ID_SUB_CHASSIS = *OpenIPMIc::ENTITY_ID_SUB_CHASSIS;
*ENTITY_ID_OTHER_CHASSIS_BOARD = *OpenIPMIc::ENTITY_ID_OTHER_CHASSIS_BOARD;
*ENTITY_ID_DISK_DRIVE_BAY = *OpenIPMIc::ENTITY_ID_DISK_DRIVE_BAY;
*ENTITY_ID_PERIPHERAL_BAY = *OpenIPMIc::ENTITY_ID_PERIPHERAL_BAY;
*ENTITY_ID_DEVICE_BAY = *OpenIPMIc::ENTITY_ID_DEVICE_BAY;
*ENTITY_ID_FAN_COOLING = *OpenIPMIc::ENTITY_ID_FAN_COOLING;
*ENTITY_ID_COOLING_UNIT = *OpenIPMIc::ENTITY_ID_COOLING_UNIT;
*ENTITY_ID_CABLE_INTERCONNECT = *OpenIPMIc::ENTITY_ID_CABLE_INTERCONNECT;
*ENTITY_ID_MEMORY_DEVICE = *OpenIPMIc::ENTITY_ID_MEMORY_DEVICE;
*ENTITY_ID_SYSTEM_MANAGEMENT_SOFTWARE = *OpenIPMIc::ENTITY_ID_SYSTEM_MANAGEMENT_SOFTWARE;
*ENTITY_ID_BIOS = *OpenIPMIc::ENTITY_ID_BIOS;
*ENTITY_ID_OPERATING_SYSTEM = *OpenIPMIc::ENTITY_ID_OPERATING_SYSTEM;
*ENTITY_ID_SYSTEM_BUS = *OpenIPMIc::ENTITY_ID_SYSTEM_BUS;
*ENTITY_ID_GROUP = *OpenIPMIc::ENTITY_ID_GROUP;
*ENTITY_ID_REMOTE_MGMT_COMM_DEVICE = *OpenIPMIc::ENTITY_ID_REMOTE_MGMT_COMM_DEVICE;
*ENTITY_ID_EXTERNAL_ENVIRONMENT = *OpenIPMIc::ENTITY_ID_EXTERNAL_ENVIRONMENT;
*ENTITY_ID_BATTERY = *OpenIPMIc::ENTITY_ID_BATTERY;
*ENTITY_ID_PROCESSING_BLADE = *OpenIPMIc::ENTITY_ID_PROCESSING_BLADE;
*ENTITY_ID_CONNECTIVITY_SWITCH = *OpenIPMIc::ENTITY_ID_CONNECTIVITY_SWITCH;
*ENTITY_ID_PROCESSOR_MEMORY_MODULE = *OpenIPMIc::ENTITY_ID_PROCESSOR_MEMORY_MODULE;
*ENTITY_ID_IO_MODULE = *OpenIPMIc::ENTITY_ID_IO_MODULE;
*ENTITY_ID_PROCESSOR_IO_MODULE = *OpenIPMIc::ENTITY_ID_PROCESSOR_IO_MODULE;
*ENTITY_ID_MGMT_CONTROLLER_FIRMWARE = *OpenIPMIc::ENTITY_ID_MGMT_CONTROLLER_FIRMWARE;
*ENTITY_ID_IPMI_CHANNEL = *OpenIPMIc::ENTITY_ID_IPMI_CHANNEL;
*ENTITY_ID_PCI_BUS = *OpenIPMIc::ENTITY_ID_PCI_BUS;
*ENTITY_ID_PCI_EXPRESS_BUS = *OpenIPMIc::ENTITY_ID_PCI_EXPRESS_BUS;
*ENTITY_ID_SCSI_BUS = *OpenIPMIc::ENTITY_ID_SCSI_BUS;
*ENTITY_ID_SATA_SAS_BUS = *OpenIPMIc::ENTITY_ID_SATA_SAS_BUS;
*ENTITY_ID_PROCESSOR_FRONT_SIDE_BUS = *OpenIPMIc::ENTITY_ID_PROCESSOR_FRONT_SIDE_BUS;
1;
